#include "control.h"
#include "servo01.h"
#include "io430.h"
#include <stdlib.h>

static int oldPosition = -1;

int readAtPosition(int position)
{
  setServoTo(position);
  
  int delay = 200 + 2 * abs(position - oldPosition);
  
  if(oldPosition < 0) // erster Aufruf dieser Funktion
  {
    // Wir wissen nicht, wo der Servo zu Beginn steht!
    // Also sicherheitshalber:
    delay = 400;
    
    // Das Initialisieren der Ausgnge fr die LEDs knnen wir hier erledigen.
    // Dann bleibt die gesamte Arbeit mit den LEDs in dieser Funktion verborgen.
    P1DIR |= BIT6 | BIT0; 
  }
  
  if(position > oldPosition)
  {
    // grne LED an, rote LED aus
    P1OUT |= BIT6;
    P1OUT &= ~BIT0;
  }
  else if(position < oldPosition)
  {
    // rote LED an, grne LED aus
    P1OUT |= BIT0;
    P1OUT &= ~BIT6;
  }
  else // position == oldPosition
  {
    // beide LEDs aus
    P1OUT &= ~(BIT0 | BIT6);
  }
  
  waitMilliseconds(delay);
  
  oldPosition = position;
  
  return readAnalog();
}

int findBestPosition(int start, int end)
{
  int bestPosition = -1;
  int maximumVoltage = -1;
  
  // Ist die bisherige Position nher bei start als bei end?
  // Dann aufwrts scannen, sonst abwrts.
  // Beim ersten Durchlauf (oldPosition == -1) starten wir unten.
  if(abs(oldPosition - start) <= abs(oldPosition - end))
  {
    for(int i = start; i <= end; i++)
    {
      int voltage = readAtPosition(i);
      if(voltage > maximumVoltage)
      {
        maximumVoltage = voltage;
        bestPosition = i;
      }
    }
  }
  else
  {
    for(int i = end; i >= start; i--)
    {
      // Dass sich hier der Code von eben wiederholt, ist unschn,
      // aber nur umstndlich zu vermeiden.
      int voltage = readAtPosition(i);
      if(voltage > maximumVoltage)
      {
        maximumVoltage = voltage;
        bestPosition = i;
      }
    }
  }
  
  return bestPosition;
}